aboutsummaryrefslogtreecommitdiffstats
path: root/java/src/com/android/inputmethod/latin/BinaryDictionaryGetter.java
diff options
context:
space:
mode:
authorKen Wakasa <kwakasa@google.com>2013-03-18 18:21:18 +0900
committerKen Wakasa <kwakasa@google.com>2013-03-18 23:15:47 +0900
commit9c3860ce461c3791891bf667edc77fe798c8d332 (patch)
tree007577ae110acf0c2e477b19c6228520ccc82689 /java/src/com/android/inputmethod/latin/BinaryDictionaryGetter.java
parent5cb0560b000f37b3fb3937f01b6d3e928afef57a (diff)
downloadlatinime-9c3860ce461c3791891bf667edc77fe798c8d332.tar.gz
latinime-9c3860ce461c3791891bf667edc77fe798c8d332.tar.xz
latinime-9c3860ce461c3791891bf667edc77fe798c8d332.zip
Rename ProductionFlag.IS_EXPERIMENTAL to USES_DEVELOPMENT_ONLY_DIAGNOSTICS
bug: 8393568 Change-Id: Ie5edf44a3627aca9416145aff56bf05bbf2a05f3
Diffstat (limited to 'java/src/com/android/inputmethod/latin/BinaryDictionaryGetter.java')
-rw-r--r--java/src/com/android/inputmethod/latin/BinaryDictionaryGetter.java5
1 files changed, 3 insertions, 2 deletions
diff --git a/java/src/com/android/inputmethod/latin/BinaryDictionaryGetter.java b/java/src/com/android/inputmethod/latin/BinaryDictionaryGetter.java
index 94598c810..f68e9f90b 100644
--- a/java/src/com/android/inputmethod/latin/BinaryDictionaryGetter.java
+++ b/java/src/com/android/inputmethod/latin/BinaryDictionaryGetter.java
@@ -289,8 +289,9 @@ final class BinaryDictionaryGetter {
// cacheWordListsFromContentProvider returns the list of files it copied to local
// storage, but we don't really care about what was copied NOW: what we want is the
// list of everything we ever cached, so we ignore the return value.
- // TODO: The experimental version is not supported by the Dictionary Pack Service yet
- if (!ProductionFlag.IS_EXPERIMENTAL) {
+ // TODO: The development-only-diagnostic version is not supported by the Dictionary Pack
+ // Service yet
+ if (!ProductionFlag.USES_DEVELOPMENT_ONLY_DIAGNOSTICS) {
// We need internet access to do the following. Only do this if the package actually
// has the permission.
if (context.checkCallingOrSelfPermission(android.Manifest.permission.INTERNET)